# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Sub-Uplevel
Epoch:		1
Version:	0.2800
Release:	19.%{__distinit}%{__distvers}
Summary:	Run a perl function in an upper stack frame
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Sub-Uplevel
Source0:	https://cpan.metacpan.org/modules/by-module/Sub/Sub-Uplevel-%{version}.tar.gz
Patch0:		Sub-Uplevel-0.28-spelling.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.17
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(constant)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(lib)
BuildRequires:	perl(Test::More) >= 0.88
# Optional Tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
# Extra Tests
%if 0%{!?perl_bootstrap:1}
%if 0%{?fedora} > 23 || 0%{?rhel} > 7
BuildRequires:	glibc-langpack-en
%endif
BuildRequires:	perl(blib)
BuildRequires:	perl(English)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire)
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Pod::Wordlist)
BuildRequires:	perl(Test::CPAN::Meta)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Portability::Files)
BuildRequires:	perl(Test::Spelling) >= 0.12, hunspell-en
BuildRequires:	perl(Test::Version) >= 1
%endif
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Carp)

# Sample build dependency cycles forcing separate bootstrap build:
#
# Pod::Coverage::TrustPod → Pod::Eventual → Mixin::Linewise → PerlIO::utf8_strict → Test::Exception → Sub::Uplevel
#
# Test::Spelling → Pod::Spell → File::ShareDir::ProjectDistDir → Path::IsDev → Test::Fatal →
#   Capture::Tiny → Parse::RecDescent → Test::Warn → Sub::Uplevel
#
# Test::Version → Test::Exception → Sub::Uplevel

# Remove bogus perl(DB) provide
%global __provides_exclude ^perl\\(DB\\)$

%description
Like Tcl's uplevel() function, but not quite so dangerous.  The
idea is just to fool caller().  All the really naughty bits of
Tcl's uplevel() are avoided.

%prep
%setup -q -n Sub-Uplevel-%{version}

# Add patch to work around hunspell's issue with ASCII apostrophes
%patch -P 0

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test
%if 0%{!?perl_bootstrap:1}
LC_ALL=en_US make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"
%endif

%files
%license LICENSE
%doc Changes CONTRIBUTING.mkdn README examples/
%{perl_vendorlib}/Sub/
%{_mandir}/man3/Sub::Uplevel.3*

%changelog
* Sat May 13 2023 Paul Howarth <paul@city-fan.org> - 1:0.2800-19
- Use SPDX-format license tag
- Drop support for building with rpm < 4.9
- Avoid use of deprecated patch syntax
- Use %%license unconditionally
- Package examples

* Fri Mar  8 2019 Paul Howarth <paul@city-fan.org> - 1:0.2800-7
- Switch upstream from search.cpan.org to metacpan.org
- Work around mock locale issues by adding buildreq glibc-langpack-en when
  running extra tests

* Thu Apr 12 2018 Paul Howarth <paul@city-fan.org> - 1:0.2800-4
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Mon Apr  3 2017 Paul Howarth <paul@city-fan.org> - 1:0.2800-1
- Update to 0.2800
  - Tests now work if '.' is not in @INC
- Update hunspell patch
- Drop support for EOL distributions prior to F-13:
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop aspell spell checker usage
  - Drop patch for building with Test::More < 0.88

* Fri Aug  5 2016 Paul Howarth <paul@city-fan.org> - 1:0.2600-1
- Update to 0.2600
  - Optimized calls to caller()
- Update patch for building with old Test::More versions

* Tue Jul 26 2016 Paul Howarth <paul@city-fan.org> - 1:0.25-5
- Fix FTBFS with no perl in the minimal buildroot
- Simplify find command using -delete
- BR: perl-generators where available
- Prefer %%global over %%define

* Tue Jan 27 2015 Paul Howarth <paul@city-fan.org> - 1:0.25-1
- Update to 0.25
  - Fixed: 00-compile.t failures under Windows (CPAN RT#98230)
  - The 00-compile.t file has been moved to a release test and is no longer
    shipped
  - Moved bug tracker to Github
  - Updated repo files explaining how to contribute
  - Enabled Travis CI
- Classify buildreqs by usage
- Use hunspell for spell checker on more recent distributions
- Add patch to work around hunspell's issue with ASCII apostrophes
- Update patch for building with old Test::More versions

* Mon Sep  1 2014 Paul Howarth <paul@city-fan.org> - 1:0.24-8
- Drop support for old distributions prior to FC-5:
  - Drop %%defattr, redundant since rpm 4.4
  - Drop patch for building with ExtUtils::MakeMaker < 6.30
  - Use Test::Requires unconditionally
- Use %%license where possible

* Fri Feb 28 2014 Paul Howarth <paul@city-fan.org> - 1:0.24-6
- Don't BR: perl(Pod::Coverage::TrustPod) when bootstrapping

* Thu Sep 19 2013 Paul Howarth <paul@city-fan.org> - 1:0.24-5
- Don't BR: perl(Pod::Wordlist::hanekomu) when bootstrapping

* Wed Sep 18 2013 Paul Howarth <paul@city-fan.org> - 1:0.24-4
- Don't BR: perl(Test::Spelling) when bootstrapping

* Mon Jul 16 2012 Paul Howarth <paul@city-fan.org> - 1:0.24-3
- Perl 5.16 post-bootstrap rebuild

* Sun Jul  8 2012 Paul Howarth <paul@city-fan.org> - 1:0.24-2
- BR:/R: perl(Carp)
- BR: perl(English) and perl(File::Temp)
- Don't run the release tests when bootstrapping
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Perl::Critic always available (except when bootstrapping)
  - Spelling dictionary is always aspell-en
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Tue Feb 21 2012 Paul Howarth <paul@city-fan.org> - 1:0.24-1
- Update to 0.24
  - Added: the $Sub::Uplevel::CHECK_FRAMES global constant to enable the frame
    depth checking and compile it out if not needed
  - Fixed: Perl 5.15 series Carp changes output format of messages (adds a
    period); this fixes the test regular expressions
- BR: perl(constant)
- Package README and README.PATCHING
- Explicitly run release tests
- Add patches to support building with Test::More < 0.88,
  ExtUtils::MakeMaker < 6.30 and no Test::Requires on older distributions
- Add buildreqs for author/release tests:
  - perl(Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire)
  - perl(Pod::Coverage::TrustPod)
  - perl(Pod::Wordlist::hanekomu)
  - perl(Test::CPAN::Meta)
  - perl(Test::Perl::Critic)
  - perl(Test::Portability::Files)
  - perl(Test::Requires)
  - perl(Test::Spelling) ≥ 0.12 and aspell-en/aspell-en-gb
  - perl(Test::Version)

* Wed Jun 29 2011 Paul Howarth <paul@city-fan.org> - 1:0.22-5
- Rebuild for perl 5.14.1 in Rawhide
- Tweak provides filter to work with rpm 4.9 onwards
- Nobody else likes macros for commands
- Fix dist tag for CentOS 6 and Scientific Linux

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 1:0.22-3
- Rebuild for perl 5.12.1 in Rawhide

* Mon May 31 2010 Paul Howarth <paul@city-fan.org> - 1:0.22-2
- Fix dist tag for RHEL-6 Beta

* Sat Feb 13 2010 Paul Howarth <paul@city-fan.org> - 1:0.22-1
- Epoch bump as per Fedora package

* Thu Feb 11 2010 Paul Howarth <paul@city-fan.org> - 0.22-2
- Drop bogus provide of perl(DB)
- Use %%{_fixperms} macro rather than our own %%{__chmod} incantation

* Wed Nov 18 2009 Paul Howarth <paul@city-fan.org> - 0.22-1
- Update to 0.22 (added ":aggressive" tag to force reloading of Exporter)
- Dist tag for rawhide no longer needs special-casing

* Sat Sep 26 2009 Paul Howarth <paul@city-fan.org> - 0.20.02-2
- Define RPM macros in global scope

* Fri Sep 12 2008 Paul Howarth <paul@city-fan.org> - 0.20.02-1
- Update to 0.2002

* Wed Sep 10 2008 Paul Howarth <paul@city-fan.org> - 0.20.01-1
- Update to 0.2001
- Add buildreq perl(ExtUtils::MakeMaker)
- Tweak dist tag macros to work on current Rawhide with three-part releasenum

* Fri Feb 15 2008 Paul Howarth <paul@city-fan.org> - 0.19.01-1
- Update to 0.1901
- Separate rpm and upstream versioning for epoch-free upgrade paths
- Include LICENSE
- "make test" no longer includes author tests

* Thu Nov  1 2007 Paul Howarth <paul@city-fan.org> - 0.18-1
- Update to 0.18
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)

* Tue Jul 31 2007 Paul Howarth <paul@city-fan.org> - 0.16-1
- Update to 0.16
- Fix dist tag for Fedora 7 onwards

* Mon Nov  6 2006 Paul Howarth <paul@city-fan.org> - 0.14-1
- Update to 0.14
- Fix argument order for find with -depth
- Add buildreqs perl(Test::Pod) and perl(Test::Pod::Coverage) and make sure
  the coverage tests are run

* Fri Sep  1 2006 Paul Howarth <paul@city-fan.org> - 0.13-2
- Fix distribution tags for development releases

* Fri Jun 23 2006 Paul Howarth <paul@city-fan.org> - 0.13-1
- Update to 0.13

* Mon May 15 2006 Paul Howarth <paul@city-fan.org> - 0.12-1
- Update to 0.12
- Add buildreq perl(Test::More) >= 0.4

* Fri Apr 21 2006 Paul Howarth <paul@city-fan.org> - 0.10-1
- Update to 0.10
- Improve portability of rpm macros
- Use search.cpan.org URLs
- Remove buildroot unconditionally in %%clean and %%install
- Don't use macros in build-time command paths, hardcode them instead

* Fri Aug 26 2005 Paul Howarth <paul@city-fan.org> - 0.09-3
- Import from Fedora Extras

* Wed Apr  6 2005 Michael Schwendt <mschwendt[AT]users.sf.net>
- rebuilt

* Thu Jul  8 2004 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.09-1
- Update to 0.09 (with license info)

* Sun Jul  4 2004 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0:0.08-0.fdr.1
- First build
